==> igniteui-react-layouts-16.16.0.tgz: package/esm2015/lib/PropertyEditorTreeTransformer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, Number_$type, String_$type, typeCast, markType } from "igniteui-react-core";
import { DescriptionTreeNode } from "igniteui-react-core";
import { JsonDictionaryObject } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { DescriptionSerializerBuilder } from "igniteui-react-core";
import { DescriptionSerializer } from "igniteui-react-core";
import { stringSplit } from "igniteui-react-core";
import { stringContains, stringReplace, stringJoin } from "igniteui-react-core";
/**
 * @hidden
 */
export let PropertyEditorTreeTransformer = /*@__PURE__*/ (() => {
    class PropertyEditorTreeTransformer extends Base {
        constructor(a, b) {
            super();
            this.a = new DescriptionTreeNode();
            this.b = null;
            this.b = a;
            this.a = new DescriptionTreeNode();
            this.a.h = b;
            let c = new JsonDictionaryObject();
        }
        h(a, b, c) {
            if (a == null) {
                return;
            }
            this.c(a, b, this.a, c, null);
        }
        c(a, b, c, d, e) {
            if (a == null) {
                return null;
            }
            let f = stringSplit(a, ['.', '['], 0);
            let g = f[0];
            let h = f.length > 1;
            let i = false;
            let j = new List$1(Number_$type, 0);
            let k = new List$1(String_$type, 0);
            if (stringContains(g, "]")) {
                i = true;
                g = stringReplace(g, "]", "");
                let l = g.split(',');
                for (let m = 0; m < l.length; m++) {
                    let n = l[m];
                    if (stringContains(n, "as")) {
                        let o = n.indexOf("as");
                        let p = n.substr(0, o).trim();
                        let q = n.substr(o + 2).trim();
                        j.add(parseInt(p));
                        k.add(q);
                        d = q;
                        g = p;
                    }
                }
            }
            let r = null;
            if (!i) {
                r = this.b.getMetadata(d, g);
            }
            else {
                r = e;
            }
            if (h) {
                if (i) {
                    let s = c.b;
                    for (let t = 0; t < j.count; t++) {
                        g = j._inner[t].toString();
                        let u = k._inner[t];
                        let v = parseInt(stringReplace(stringReplace(g, "[", ""), "]", ""));
                        {
                            let w = new List$1(Base.$, 0);
                            for (let x = 0; x <= v; x++) {
                                if (s != null && x < s.length) {
                                    let y = s[x];
                                    if (typeCast(DescriptionTreeNode.$, y) !== null && x == v) {
                                        y.h = u;
                                    }
                                    w.add1(y);
                                }
                                else {
                                    let z = this.d(e, true, u);
                                    if (z != null) {
                                        w.add1(z);
                                    }
                                }
                            }
                            s = w.toArray();
                            let aa = s[v];
                            let ab = new List$1(String_$type, 1, f);
                            ab.removeAt(0);
                            let ac = r.collectionElementType;
                            if (u != null) {
                                ac = u;
                            }
                            let ad = this.c(stringJoin(".", ...ab.toArray()), b, aa, ac, r);
                            if (ad != null) {
                                s[v] = ad;
                            }
                            c.b = s;
                        }
                    }
                }
                else {
                    let ae = c;
                    if (!ae.b(g)) {
                        ae.n(g, this.d(r, false, null), r);
                    }
                    let af = ae.a(g);
                    let ag = new List$1(String_$type, 1, f);
                    ag.removeAt(0);
                    let ah = this.c(stringJoin(".", ...ag.toArray()), b, af, r.specificExternalType, r);
                    if (ah != null) {
                        ae.n(g, ah, r);
                    }
                }
            }
            else {
                let ai = c;
                ai.n(g, this.e(b, r), r);
            }
            return null;
        }
        f(a) {
            if (a == null) {
                return null;
            }
            if (a.length < 1) {
                return "";
            }
            return a.substr(0, 1).toLowerCase() + a.substr(1);
        }
        e(a, b) {
            if (a == null) {
                return null;
            }
            if (b == null) {
                return null;
            }
            switch (b.knownType) {
                case 10: return a;
                case 7: return a;
                case 4: return a.toString();
                case 6: return a;
                case 9: return a;
                case 5: return a.toString();
                case 16: return a;
                case 20: return a;
                case 15: return a;
                case 3: return a;
                case 19: return a;
                case 8: return a;
                case 13: return a;
                case 18: return a;
                case 1: return a;
                case 11: return a;
                case 14: return a;
                case 12: return a;
                case 2: return a;
                case 21: return a;
                case 17: return a;
                case 0: return a;
            }
            return null;
        }
        d(a, b, c) {
            if (!b && (a.knownType == 10 || a.knownType == 9)) {
                return new Array(0);
            }
            else {
                let d = new DescriptionTreeNode();
                if (c != null) {
                    d.h = c;
                }
                else {
                    d.h = a.specificExternalType != null ? a.specificExternalType : a.specificType;
                }
                return d;
            }
        }
        g() {
            let a = new DescriptionSerializerBuilder();
            let b = new DescriptionSerializer();
            let c = "root";
            a.f("{");
            a.i();
            a.f("\"descriptions\": {");
            a.i();
            a.e("\"" + c + "\"");
            a.e(": ");
            b.s(this.b, this.a, a);
            a.f("");
            a.h();
            a.e("}");
            a.h();
            a.f("}");
            return a.toString();
        }
    }
    PropertyEditorTreeTransformer.$t = /*@__PURE__*/ markType(PropertyEditorTreeTransformer, 'PropertyEditorTreeTransformer');
    return PropertyEditorTreeTransformer;
})();

==> igniteui-react-layouts-16.16.2.tgz: package/esm2015/lib/PropertyEditorTreeTransformer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, Number_$type, String_$type, typeCast, markType } from "igniteui-react-core";
import { DescriptionTreeNode } from "igniteui-react-core";
import { JsonDictionaryObject } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { DescriptionSerializerBuilder } from "igniteui-react-core";
import { DescriptionSerializer } from "igniteui-react-core";
import { stringSplit } from "igniteui-react-core";
import { stringContains, stringReplace, stringJoin } from "igniteui-react-core";
/**
 * @hidden
 */
export let PropertyEditorTreeTransformer = /*@__PURE__*/ (() => {
    class PropertyEditorTreeTransformer extends Base {
        constructor(a, b) {
            super();
            this.a = new DescriptionTreeNode();
            this.b = null;
            this.b = a;
            this.a = new DescriptionTreeNode();
            this.a.h = b;
            let c = new JsonDictionaryObject();
        }
        h(a, b, c) {
            if (a == null) {
                return;
            }
            this.c(a, b, this.a, c, null);
        }
        c(a, b, c, d, e) {
            if (a == null) {
                return null;
            }
            let f = stringSplit(a, ['.', '['], 0);
            let g = f[0];
            let h = f.length > 1;
            let i = false;
            let j = new List$1(Number_$type, 0);
            let k = new List$1(String_$type, 0);
            if (stringContains(g, "]")) {
                i = true;
                g = stringReplace(g, "]", "");
                let l = g.split(',');
                for (let m = 0; m < l.length; m++) {
                    let n = l[m];
                    if (stringContains(n, "as")) {
                        let o = n.indexOf("as");
                        let p = n.substr(0, o).trim();
                        let q = n.substr(o + 2).trim();
                        j.add(parseInt(p));
                        k.add(q);
                        d = q;
                        g = p;
                    }
                }
            }
            let r = null;
            if (!i) {
                r = this.b.getMetadata(d, g);
            }
            else {
                r = e;
            }
            if (h) {
                if (i) {
                    let s = c.b;
                    for (let t = 0; t < j.count; t++) {
                        g = j._inner[t].toString();
                        let u = k._inner[t];
                        let v = parseInt(stringReplace(stringReplace(g, "[", ""), "]", ""));
                        {
                            let w = new List$1(Base.$, 0);
                            for (let x = 0; x <= v; x++) {
                                if (s != null && x < s.length) {
                                    let y = s[x];
                                    if (typeCast(DescriptionTreeNode.$, y) !== null && x == v) {
                                        y.h = u;
                                    }
                                    w.add1(y);
                                }
                                else {
                                    let z = this.d(e, true, u);
                                    if (z != null) {
                                        w.add1(z);
                                    }
                                }
                            }
                            s = w.toArray();
                            let aa = s[v];
                            let ab = new List$1(String_$type, 1, f);
                            ab.removeAt(0);
                            let ac = r.collectionElementType;
                            if (u != null) {
                                ac = u;
                            }
                            let ad = this.c(stringJoin(".", ...ab.toArray()), b, aa, ac, r);
                            if (ad != null) {
                                s[v] = ad;
                            }
                            c.b = s;
                        }
                    }
                }
                else {
                    let ae = c;
                    if (!ae.b(g)) {
                        ae.n(g, this.d(r, false, null), r);
                    }
                    let af = ae.a(g);
                    let ag = new List$1(String_$type, 1, f);
                    ag.removeAt(0);
                    let ah = this.c(stringJoin(".", ...ag.toArray()), b, af, r.specificExternalType, r);
                    if (ah != null) {
                        ae.n(g, ah, r);
                    }
                }
            }
            else {
                let ai = c;
                ai.n(g, this.e(b, r), r);
            }
            return null;
        }
        f(a) {
            if (a == null) {
                return null;
            }
            if (a.length < 1) {
                return "";
            }
            return a.substr(0, 1).toLowerCase() + a.substr(1);
        }
        e(a, b) {
            if (a == null) {
                return null;
            }
            if (b == null) {
                return null;
            }
            switch (b.knownType) {
                case 10: return a;
                case 7: return a;
                case 4: return a.toString();
                case 6: return a;
                case 9: return a;
                case 5: return a.toString();
                case 16: return a;
                case 20: return a;
                case 15: return a;
                case 3: return a;
                case 19: return a;
                case 8: return a;
                case 13: return a;
                case 18: return a;
                case 1: return a;
                case 11: return a;
                case 14: return a;
                case 12: return a;
                case 2: return a;
                case 21: return a;
                case 17: return a;
                case 0: return a;
            }
            return null;
        }
        d(a, b, c) {
            if (!b && (a.knownType == 10 || a.knownType == 9)) {
                return new Array(0);
            }
            else {
                let d = new DescriptionTreeNode();
                if (c != null) {
                    d.h = c;
                }
                else {
                    d.h = a.specificExternalType != null ? a.specificExternalType : a.specificType;
                }
                return d;
            }
        }
        g() {
            let a = new DescriptionSerializerBuilder();
            let b = new DescriptionSerializer();
            let c = "root";
            a.f("{");
            a.i();
            a.f("\"descriptions\": {");
            a.i();
            a.e("\"" + c + "\"");
            a.e(": ");
            b.t(this.b, this.a, a);
            a.f("");
            a.h();
            a.e("}");
            a.h();
            a.f("}");
            return a.toString();
        }
    }
    PropertyEditorTreeTransformer.$t = /*@__PURE__*/ markType(PropertyEditorTreeTransformer, 'PropertyEditorTreeTransformer');
    return PropertyEditorTreeTransformer;
})();
